package tech.nevets.deepj;
import org.json.JSONArray;
import org.json.JSONObject;
import java.io.IOException;
import java.net.URI;
import java.net.URLEncoder;
import java.net.http.HttpClient;
import java.net.http.HttpRequest;
import java.net.http.HttpResponse;
import java.nio.charset.StandardCharsets;
public class Translator {
    Request request;
    public Translator(String authKey) {
        request = new Request(authKey);
    }
    public String translate(Language langToTranslateTo, String sourceMessage) {
        String response = "Error processing request";
        try {
            response = request.get(langToTranslateTo, sourceMessage);
        } catch (IOException | InterruptedException e) {
            System.out.println("Error processing request");
            e.printStackTrace();
        }
        String message = "Error Processing Request";
        JSONObject jo = new JSONObject(response);
        JSONArray ja = jo.getJSONArray("translations");
        for (int i = 0; i < ja.length(); i++) {
            JSONObject joo = ja.getJSONObject(i);
            message = joo.getString("text");
        }
        return message;
    }
    protected static class Request {
        private final String authKey;
        public Request(String authKey) {
            this.authKey = authKey;
        }
        public String get(Language langEnum, String message) throws IOException, InterruptedException {
            String encodedAuthKey = URLEncoder.encode(authKey, StandardCharsets.UTF_8);
            String encodedMessage = URLEncoder.encode(message, StandardCharsets.UTF_8);
            HttpClient client = HttpClient.newHttpClient();
            HttpRequest request = HttpRequest.newBuilder().GET()
                    .header("Accept","*/*")
                    .header("Content-Type", "application/x-www-form-urlencoded")
                    .uri(URI.create("https://api-free.deepl.com/v2/translate?auth_key=" + encodedAuthKey + "&target_lang=" + langEnum.getApiString() + "&text=" + encodedMessage)).build();
            HttpResponse<String> response = client.send(request, HttpResponse.BodyHandlers.ofString());
            return response.body();
        }
    }

    public enum Language {
        Bulgarian("BG"),
        Czech("CS"),
        Danish("DA"),
        German("DE"),
        Greek("EL"),
        EnglishUK("EN-GB"),
        EnglishUS("EN-US"),
        Spanish("ES"),
        Estonian("ET"),
        Finish("FI"),
        French("FR"),
        Hungarian("HU"),
        Italian("IT"),
        Japanese("JA"),
        Lithuanian("LT"),
        Latvian("LV"),
        Dutch("NL"),
        Polish("PL"),
        PortugueseBrazil("PT-BR"),
        PortuguesePortugal("PT-PT"),
        Romanian("RO"),
        Russian("RU"),
        Slovak("SK"),
        Slovenian("SL"),
        Swedish("SV"),
        Chinese("ZH");
        private final String apiString;
        Language(String apiString) {
            this.apiString = apiString;
        }
        public String getApiString() {
            return this.apiString;
        }
    }
}